@@ -102,7 +102,7 @@ class SijaxFlaskTestCase(unittest.TestCase):
             self.assertTrue('Sijax.setRequestUri("/");' in js)
             self.assertFalse('Sijax.setRequestUri("http://something.else/");' in js)
 
-        # Ensure that the changed request uri was valid for the previous request only
+        # Test that a more complex request url (with query string, etc) works
         with app.test_request_context('/relative/url?query=string&is=here'):
             app.preprocess_request()
 
@@ -208,7 +208,7 @@ class SijaxFlaskTestCase(unittest.TestCase):
     def test_process_request_returns_a_string_or_a_flask_response_object(self):
         # SijaxHelper.process_request should return a string for regular functions
         # and a Flask.Response object for functions that use a generator (streaming functions)
-        from sijax.response.StreamingIframeResponse import StreamingIframeResponse
+        from sijax.response import StreamingIframeResponse
 
         app = flask.Flask(__name__)
         helper = init_sijax(app)
